=======
History
=======

0.0.1 (2019-09-05)
------------------

* First release on GitHub.
* First release on PyPI.

0.1.0 (2019-10-25)
------------------

* Improved documentation.
* Added pandas dataframe class extension for ADNI
